.. octavia-specs documentation master file

=====================
Octavia Documentation
=====================

Getting started
---------------

.. toctree::
   :maxdepth: 1

   main/introduction.rst
   main/glossary.rst

For users
---------

.. toctree::
   :maxdepth: 1

   guides/basic-cookbook.rst
   guides/l7.rst
   guides/l7-cookbook.rst

For developers
--------------

.. toctree::
   :maxdepth: 1

   guides/dev-quick-start.rst
   main/CONSTITUTION.rst
   main/HACKING.rst
   devref/flows.rst
   main/gmr.rst

For operators
-------------

.. toctree::
   :maxdepth: 1

   guides/dev-quick-start.rst
   guides/operator-maintenance.rst
   main/configref.rst
   main/Anchor.rst
   devref/apache-httpd.rst

====
APIs
====

.. toctree::
   :glob:
   :maxdepth: 1

   api/octaviaapi.rst
   api/haproxy-amphora-api.rst

====================
Design Documentation
====================

Version 0.5 (liberty)
---------------------

.. toctree::
   :glob:
   :maxdepth: 1

   design/version0.5/*

======================
Project Specifications
======================

Version 0.5 (liberty)
---------------------

.. toctree::
   :glob:
   :maxdepth: 1

   specs/version0.5/*

Version 0.8 (mitaka)
--------------------

.. toctree::
   :glob:
   :maxdepth: 1

   specs/version0.8/*

Version 0.9 (newton)
--------------------

.. toctree::
   :glob:
   :maxdepth: 1

   specs/version0.9/*

Version 1.0
-----------

.. toctree::
   :glob:
   :maxdepth: 1

   specs/version1/*

==================
Indices and tables
==================

* :ref:`search`
